==> haskell-path-0.9.5-148-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-path.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 path
version:              0.9.5
visibility:           public
id:                   path-0.9.5-3ik2i70AEeO1G8ny8SRIuV
key:                  path-0.9.5-3ik2i70AEeO1G8ny8SRIuV
license:              BSD-3-Clause
copyright:            2015–2018 FP Complete
maintainer:           Chris Done <chrisdone@fpcomplete.com>
author:               Chris Done <chrisdone@fpcomplete.com>
synopsis:             Support for well-typed paths
description:          Support for well-typed paths.
category:             System, Filesystem
abi:                  6735bc6aa5088389953073605f49caaa
exposed:              True
exposed-modules:
    Path Path.Internal Path.Internal.Posix Path.Internal.Windows
    Path.Posix Path.Windows

import-dirs:          /usr/lib/ghc-9.4.8/site-local/path-0.9.5
library-dirs:         /usr/lib/ghc-9.4.8/site-local/path-0.9.5
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/path-0.9.5
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-path
hs-libraries:         HSpath-0.9.5-3ik2i70AEeO1G8ny8SRIuV
depends:
    aeson-2.1.2.1-9rGsBPhyshTKvPzkopJx8r base-4.17.2.1 deepseq-1.4.8.0
    exceptions-0.10.5 filepath-1.4.2.2
    hashable-1.4.7.0-LvsgkXc0RJl9ehxeji9DTo template-haskell-2.19.0.0
    text-2.0.2

haddock-interfaces:   /usr/share/doc/haskell-path/html/path.haddock
haddock-html:         /usr/share/doc/haskell-path/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-path-0.9.5-149-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-path.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 path
version:              0.9.5
visibility:           public
id:                   path-0.9.5-A9z9fR8KvJ4LScQXHVsRJ3
key:                  path-0.9.5-A9z9fR8KvJ4LScQXHVsRJ3
license:              BSD-3-Clause
copyright:            2015–2018 FP Complete
maintainer:           Chris Done <chrisdone@fpcomplete.com>
author:               Chris Done <chrisdone@fpcomplete.com>
synopsis:             Support for well-typed paths
description:          Support for well-typed paths.
category:             System, Filesystem
abi:                  13e8233cb0094f512be2bf9f7b6ae0d1
exposed:              True
exposed-modules:
    Path Path.Internal Path.Internal.Posix Path.Internal.Windows
    Path.Posix Path.Windows

import-dirs:          /usr/lib/ghc-9.4.8/site-local/path-0.9.5
library-dirs:         /usr/lib/ghc-9.4.8/site-local/path-0.9.5
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/path-0.9.5
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-path
hs-libraries:         HSpath-0.9.5-A9z9fR8KvJ4LScQXHVsRJ3
depends:
    aeson-2.1.2.1-3LOl3stht3x9JybSpHkoQT base-4.17.2.1 deepseq-1.4.8.0
    exceptions-0.10.5 filepath-1.4.2.2
    hashable-1.4.7.0-bh6X3bZPF56LQTYQ27khw template-haskell-2.19.0.0
    text-2.0.2

haddock-interfaces:   /usr/share/doc/haskell-path/html/path.haddock
haddock-html:         /usr/share/doc/haskell-path/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
